@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw Guitar Chord Diagrams
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -58,6 +58,21 @@ has font => (
 );
 
 
+has notes => (
+    is      => 'ro',
+    default => sub {
+        {
+            1 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
+            2 => [qw/B C  Db D  Eb E F  Gb G  Ab A Bb/],
+            3 => [qw/G Ab A  Bb B  C Db D  Eb E  F Gb/],
+            4 => [qw/D Eb E  F  Gb G Ab A  Bb B  C Db/],
+            5 => [qw/A Bb B  C  Db D Eb E  F  Gb G Ab/],
+            6 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
+        }
+    },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { 0 },
@@ -73,14 +88,6 @@ sub draw {
     my $SPACE = $self->size;
 
     my @chord;
-    my %notes = (
-        1 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
-        2 => [qw/B C  Db D  Eb E F  Gb G  Ab A Bb/],
-        3 => [qw/G Ab A  Bb B  C Db D  Eb E  F Gb/],
-        4 => [qw/D Eb E  F  Gb G Ab A  Bb B  C Db/],
-        5 => [qw/A Bb B  C  Db D Eb E  F  Gb G Ab/],
-        6 => [qw/E F  Gb G  Ab A Bb B  C  Db D Eb/],
-    );
 
     # Setup a new image
     my $i = Imager->new(
@@ -147,9 +154,9 @@ sub draw {
             );
         }
         elsif ( $note =~ /[oO0]/ ) {
-            push @chord, $notes{$string}[0];
-
-            print "O at 0,$string = $notes{$string}[0]\n" if $self->verbose;
+            my $temp = $self->notes->{$string}[0];
+            push @chord, $temp;
+            print "O at 0,$string = $temp\n" if $self->verbose;
 
             $i->string(
                 font  => $font,
@@ -162,9 +169,9 @@ sub draw {
             );
         }
         else {
-            push @chord, $notes{$string}[$self->position + $note - 1];
-
-            print "Dot at $note,$string = $notes{$string}[$self->position + $note - 1]\n" if $self->verbose;
+            my $temp = $self->notes->{$string}[$self->position + $note - 1];
+            push @chord, $temp;
+            print "Dot at $note,$string = $temp\n" if $self->verbose;
 
             $i->circle(
                 color => $BLACK,
@@ -210,7 +217,7 @@ Music::GuitarChordDiagram - Draw Guitar Chord Diagrams
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -224,6 +231,7 @@ version 0.0100
     size       => 30,
     outfile    => 'chord-diagram',
     font       => '/path/to/TTF/font.ttf',
+    notes      => { 1 => [qw/D Eb E F .../], 2 => [qw/.../], },
     verbose    => 1,
   );
 
@@ -323,6 +331,21 @@ The TTF font to use when rendering the diagram.
 
 Default: /opt/X11/share/fonts/TTF/VeraMono.ttf
 
+=head2 notes
+
+  $notes = $dia->notes;
+
+A hashref of string keys and note list values to use in computing the chord.
+
+Default:
+
+  1 => [ E F  Gb G  Ab A Bb B  C  Db D Eb ]
+  2 => [ B C  Db D  Eb E F  Gb G  Ab A Bb ]
+  3 => [ G Ab A  Bb B  C Db D  Eb E  F Gb ]
+  4 => [ D Eb E  F  Gb G Ab A  Bb B  C Db ]
+  5 => [ A Bb B  C  Db D Eb E  F  Gb G Ab ]
+  6 => [ E F  Gb G  Ab A Bb B  C  Db D Eb ]
+
 =head2 verbose
 
   $verbose = $dia->verbose;
